"use client";
import { Phone, Heart, ShoppingCart, User } from "lucide-react";
import Link from "next/link";
import useSWR from "swr";
import Image from "next/image";
import { FiSearch } from "react-icons/fi";
import {
  NavigationMenu,
  NavigationMenuContent,
  NavigationMenuIndicator,
  NavigationMenuItem,
  NavigationMenuLink,
  NavigationMenuList,
  NavigationMenuTrigger,
  NavigationMenuViewport,
} from "@/components/ui/navigation-menu";

import { navigationMenuTriggerStyle } from "@/components/ui/navigation-menu";
import { useState, useEffect } from "react";
import { Search } from "lucide-react";
import { AuthModal } from "../components/auth-modal";
import { useAuth } from "../context/AuthContext";
import {
  DropdownMenu,
  DropdownMenuContent,
  DropdownMenuItem,
  DropdownMenuTrigger,
} from "@/components/ui/dropdown-menu";
import { useRouter } from "next/navigation";
import SearchContainer from "./searchContainer";
import debounce from "debounce";
import { useCart } from "../context/CartContext";
const fetcher = async (url) => {
  const response = await fetch(url);
  const data = await response.json();
  if (!data.success) {
    throw new Error(data.message || "Failed to fetch search results");
  }
  return data;
};
export default function navbar() {
  const router = useRouter();
  const { user, logout } = useAuth();
  const [query, setQuery] = useState("");
  const [isLoginOpen, setIsLoginOpen] = useState(false);

  const [iconSize, setIconSize] = useState(14);

  useEffect(() => {
    const handleResize = () => {
      if (window.innerWidth < 768 && window.innerWidth < 1024) {
        // md screen (768px - 1023px)
        setIconSize(18);
      } else {
        setIconSize(20);
      }
    };

    handleResize(); // Check on mount
    window.addEventListener("resize", handleResize);

    return () => window.removeEventListener("resize", handleResize);
  }, []);
  const [searchKey, setSearchKey] = useState(null); // Controls when to fetch

  // Construct the API URL based on query
  const getSearchUrl = () => {
    if (!query.trim()) return null; // Don't fetch if query is empty
    return `${
      process.env.NEXT_PUBLIC_BASE_URL
    }searchProducts?query=${encodeURIComponent(query)}`;
  };

  // Use SWR to fetch data only when searchKey is set
  const { data, error, isLoading } = useSWR(
    searchKey ? getSearchUrl() : null,
    fetcher,
    {
      revalidateOnFocus: false, // Disable refetch on window focus
      revalidateOnReconnect: false, // Disable refetch on reconnect
    }
  );

  // Extract products from data
  const products = data?.products || [];
  const debouncedSetSearchKey = debounce((value) => setSearchKey(value), 300);
  // Handle search submission
  const handleSearch = (e) => {
    e.preventDefault();
    if (!query.trim()) {
      setSearchKey(null);
      return;
    }
    debouncedSetSearchKey(query);
  };
  const { cartCount } = useCart();
  const totalItems = cartCount.reduce(
    (sum, item) => sum + (item.quantity || 0),
    0
  );
  return (
    <>
      <div className=" md:block hidden relative shadow-lg py-3 px-4 z-50">
        <div className="flex justify-around items-center">
          <div className="flex  text-black ">
            <NavigationMenu>
              <NavigationMenuList>
                <NavigationMenuItem>
                  <Link href="../" legacyBehavior passHref>
                    <NavigationMenuLink
                      className={navigationMenuTriggerStyle()}
                    >
                      Home
                    </NavigationMenuLink>
                  </Link>
                </NavigationMenuItem>
              </NavigationMenuList>
            </NavigationMenu>

            {/* <NavigationMenu>
              <NavigationMenuList>
                <NavigationMenuItem>
                  <NavigationMenuTrigger>Category</NavigationMenuTrigger>
                  <NavigationMenuContent>
                    <Link href="" legacyBehavior passHref>
                      <NavigationMenuLink
                        className={navigationMenuTriggerStyle()}
                      >
                        Category 1
                      </NavigationMenuLink>
                    </Link>
                    <Link href="" legacyBehavior passHref>
                      <NavigationMenuLink
                        className={navigationMenuTriggerStyle()}
                      >
                        Category 1
                      </NavigationMenuLink>
                    </Link>
                  </NavigationMenuContent>
                </NavigationMenuItem>
              </NavigationMenuList>
            </NavigationMenu> */}

            <NavigationMenu>
              <NavigationMenuList>
                <NavigationMenuItem>
                  <Link href="../products" legacyBehavior passHref>
                    <NavigationMenuLink
                      className={navigationMenuTriggerStyle()}
                    >
                      Products
                    </NavigationMenuLink>
                  </Link>
                </NavigationMenuItem>
              </NavigationMenuList>
            </NavigationMenu>

            <NavigationMenu>
              <NavigationMenuList>
                <NavigationMenuItem>
                  <Link href="../about" legacyBehavior passHref>
                    <NavigationMenuLink
                      className={navigationMenuTriggerStyle()}
                    >
                      About
                    </NavigationMenuLink>
                  </Link>
                </NavigationMenuItem>
              </NavigationMenuList>
            </NavigationMenu>
            <NavigationMenu>
              <NavigationMenuList>
                <NavigationMenuItem>
                  <NavigationMenuTrigger>Language</NavigationMenuTrigger>
                  <NavigationMenuContent>
                    <Link href="" legacyBehavior passHref>
                      <NavigationMenuLink
                        className={navigationMenuTriggerStyle()}
                      >
                        English
                      </NavigationMenuLink>
                    </Link>
                  </NavigationMenuContent>
                </NavigationMenuItem>
              </NavigationMenuList>
            </NavigationMenu>
          </div>
          <div>
            <h2 className="flex gap-2 text-black">
              <Phone size={18} /> +123 ( 456 ) ( 7890 )
            </h2>
          </div>
        </div>
      </div>

      <nav className="shadow-lg  px-2 sticky top-0 z-40  bg-white ">
        <div className="flex justify-between gap-2 items-center py-4 max-w-7xl mx-auto">
          <Link href="../">
            <Image
              src="/assets/Logo.svg"
              alt="logo"
              className="relative w-[150] lg:w-[150]"
              width={150}
              height={100}
            />
          </Link>

          <div>
            {/* Search Bar */}
            <form
              onSubmit={handleSearch}
              className="flex w-full max-w-lg border rounded-md overflow-hidden"
            >
              <input
                type="text"
                placeholder="Search For items..."
                className="flex-1 w-full p-2 outline-none border-none text-xs md:text-custom16 xl:w-[400px]"
                value={query}
                onChange={(e) => setQuery(e.target.value)}
              />
              {/* <select
                className="border-l text-sm px-1 lg:px-3 outline-none md:block hidden"

                onChange={(e) => setCategory(e.target.value)}
              >
                <option>All Categories</option>
                <option>Electronics</option>
                <option>Fashion</option>
                <option>Home & Kitchen</option>
              </select> */}
              <button
                type="submit"
                className="bg-primary text-white px-4 flex items-center justify-center"
              >
                <FiSearch size={20} /> {/* Adjust iconSize as needed */}
              </button>
            </form>

            {/* Display Loading, Error, or Results */}
            <SearchContainer
              query={query}
              searchKey={searchKey}
              isLoading={isLoading}
              error={error}
              products={data?.products || []}
              handleSearch={handleSearch}
            />
          </div>

          <div>
            <ul className="text-sm flex gap-3 md:gap-8 font-[500] text-black">
              <li>
                <Link
                  href="../wishList"
                  className="flex items-center gap-1 cursor-pointer"
                >
                  <Heart size={iconSize} />
                  <span className="hidden md:inline">Wishlist</span>
                </Link>
              </li>
              {/* <li>
                <Link
                  href="../cart"
                  className="flex items-center gap-1 cursor-pointer"
                >
                  <ShoppingCart size={iconSize} />
                  <span className="hidden md:inline">Cart</span>
                </Link>
              </li> */}
              <li className="relative">
                <Link
                  href="../cart"
                  className="flex items-center gap-1 cursor-pointer"
                >
                  <div className="relative">
                    <ShoppingCart size={iconSize} />
                    {/* Badge */}
                    {totalItems > 0 && (
                      <span className="absolute -top-2 -right-1 bg-primary text-white text-[10px] font-bold w-4 h-4 rounded-full flex items-center justify-center">
                        {totalItems}
                      </span>
                    )}
                  </div>
                  <span className="hidden md:inline">Cart</span>
                </Link>
              </li>

              <li className="flex items-center gap-1 cursor-pointer">
                {user ? (
                  // If user is logged in, show dropdown
                  <DropdownMenu>
                    <DropdownMenuTrigger className="flex items-center gap-2">
                      <User size={iconSize} />
                      <span className="hidden md:inline">{user.user_name}</span>
                    </DropdownMenuTrigger>
                    <DropdownMenuContent>
                      <DropdownMenuItem onClick={() => router.push("/setting")}>
                        Profile
                      </DropdownMenuItem>
                      <DropdownMenuItem
                        onClick={logout}
                        className="text-red-500"
                      >
                        Logout
                      </DropdownMenuItem>
                    </DropdownMenuContent>
                  </DropdownMenu>
                ) : (
                  // If user is not logged in, show login button
                  <div
                    onClick={() => setIsLoginOpen(true)}
                    className="flex items-center gap-2"
                  >
                    <User size={iconSize} />
                    <span className="hidden md:inline">Login</span>
                  </div>
                )}
              </li>
            </ul>
          </div>
        </div>
      </nav>
      <AuthModal isOpen={isLoginOpen} setIsOpen={setIsLoginOpen} />
    </>
  );
}
